==> core_models-0.2.2.gem: app/controllers/core_models/i18n/countries_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class I18n::CountriesController < CoreModelsController
    # GET /i18n/countries
    # GET /i18n/countries.json
    def index
      @i18n_countries = I18n::Country.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @i18n_countries }
      end
    end

    # GET /i18n/countries/1
    # GET /i18n/countries/1.json
    def show
      @i18n_country = I18n::Country.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @i18n_country }
      end
    end

    # GET /i18n/countries/new
    # GET /i18n/countries/new.json
    def new
      @i18n_country = I18n::Country.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @i18n_country }
      end
    end

    # GET /i18n/countries/1/edit
    def edit
      @i18n_country = I18n::Country.find(params[:id])
    end

    # POST /i18n/countries
    # POST /i18n/countries.json
    def create
      @i18n_country = I18n::Country.new(params[:i18n_country])

      respond_to do |format|
        if @i18n_country.save
          format.html { redirect_to @i18n_country, :notice => 'Country was successfully created.' }
          format.json { render :json => @i18n_country, :status => :created, :location => @i18n_country }
        else
          format.html { render :action => "new" }
          format.json { render :json => @i18n_country.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /i18n/countries/1
    # PUT /i18n/countries/1.json
    def update
      @i18n_country = I18n::Country.find(params[:id])

      respond_to do |format|
        if @i18n_country.update_attributes(params[:i18n_country])
          format.html { redirect_to @i18n_country, :notice => 'Country was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @i18n_country.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /i18n/countries/1
    # DELETE /i18n/countries/1.json
    def destroy
      @i18n_country = I18n::Country.find(params[:id])
      @i18n_country.destroy

      respond_to do |format|
        format.html { redirect_to i18n_countries_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/i18n/countries_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class I18n::CountriesController < CoreModelsController
    # GET /i18n/countries
    # GET /i18n/countries.json
    def index
      @i18n_countries = I18n::Country.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @i18n_countries }
      end
    end

    # GET /i18n/countries/1
    # GET /i18n/countries/1.json
    def show
      @i18n_country = I18n::Country.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @i18n_country }
      end
    end

    # GET /i18n/countries/new
    # GET /i18n/countries/new.json
    def new
      @i18n_country = I18n::Country.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @i18n_country }
      end
    end

    # GET /i18n/countries/1/edit
    def edit
      @i18n_country = I18n::Country.find(params[:id])
    end

    # POST /i18n/countries
    # POST /i18n/countries.json
    def create
      @i18n_country = I18n::Country.new(params[:i18n_country])

      respond_to do |format|
        if @i18n_country.save
          format.html { redirect_to @i18n_country, :notice => 'Country was successfully created.' }
          format.json { render :json => @i18n_country, :status => :created, :location => @i18n_country }
        else
          format.html { render :action => "new" }
          format.json { render :json => @i18n_country.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /i18n/countries/1
    # PUT /i18n/countries/1.json
    def update
      @i18n_country = I18n::Country.find(params[:id])

      respond_to do |format|
        if @i18n_country.update(params[:i18n_country])
          format.html { redirect_to @i18n_country, :notice => 'Country was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @i18n_country.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /i18n/countries/1
    # DELETE /i18n/countries/1.json
    def destroy
      @i18n_country = I18n::Country.find(params[:id])
      @i18n_country.destroy

      respond_to do |format|
        format.html { redirect_to i18n_countries_url }
        format.json { head :no_content }
      end
    end
  end
end
